# Comment Policy

Please keep the discussion on topic and respect the opinions of others. We reserve the right to delete comments that 
are off-topic, rude, or disrespectful. We also reserve the right to ban users who repeatedly violate our comment policy.

## Comments

<script
   type="text/javascript"
   src="https://utteranc.es/client.js"
   async="async"
   repo="haiiliin/abqpy"
   issue-term="pathname"
   theme="github-light"
   label="💬 comment"
   crossorigin="anonymous"
/>
